@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2019-2020 -- leonerd@leonerd.org.uk
 
-package Object::Pad 0.43;
+package Object::Pad 0.44;
 
 use v5.14;
 use warnings;
@@ -72,7 +72,7 @@ which helps create the object instances. This may respond to passed arguments,
 automatically assigning values of slots, and invoking other blocks of code
 provided by the class. It proceeds in the following stages:
 
-=head3 BUILDARGS
+=head3 The BUILDARGS phase
 
 If the class provides a C<BUILDARGS> class method, that is used to mangle the
 list of arguments before the C<BUILD> blocks are called. Note this must be a
@@ -93,14 +93,14 @@ The constructor will also check for required parameters (these are all the
 parameters for slots that do not have default initialisation expressions). If
 any of these are missing an exception is thrown.
 
-=head3 BUILD
+=head3 The BUILD phase
 
 As part of the construction process, the C<BUILD> block of every component
 class will be invoked, passing in the list of arguments the constructor was
 invoked with. Each class should perform its required setup behaviour, but does
 not need to chain to the C<SUPER> class first; this is handled automatically.
 
-=head3 ADJUST
+=head3 The ADJUST phase
 
 Finally, before the new object is returned from the constructor, the C<ADJUST>
 block of every component class is invoked. This happens after the slots are
@@ -402,6 +402,17 @@ argument checking similar to that used by subroutine signatures, to ensure the
 correct number of arguments are passed - usually zero, but exactly one in the
 case of a C<:writer> method.
 
+=head3 :weak
+
+I<Since version 0.44.>
+
+Generated code which sets the value of this slot will weaken it if it contains
+a reference. This applies to within the constructor if C<:param> is given, and
+to a C<:writer> accessor method. Note that this I<only> applies to
+automatically generated code; not normal code written in regular method
+bodies. If you assign into the slot variable you must remember to call
+C<Scalar::Util::weaken> yourself.
+
 =head3 :param, :param(NAME)
 
 I<Since version 0.41.>
